@@ -29,11 +29,20 @@
 #ifdef  _MSWINDOWS_
 #include <process.h>
 #include <winreg.h>
+#include <conio.h>
 #else
 #include <sys/wait.h>
 #include <sys/ioctl.h>
+#ifdef  HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
+#ifdef  HAVE_TERMIOS_H
+#include <termios.h>
+#endif
+#ifdef  HAVE_TERMIO_H
+#include <termio.h>
+#endif
+#endif
 
 #ifdef  HAVE_SYS_RESOURCE_H
 #include <sys/time.h>
@@ -1707,10 +1716,165 @@ exit:
     return 0;
 }
 
+char *shell::getpass(const char *prompt, char *buffer, size_t size)
+{
+    size_t pos = 0;
+    fputs(prompt, stderr);
+
+    while(pos < size - 1) {
+        buffer[pos] = (char)getch();
+        if(buffer[pos] == '\r' || buffer[pos] == '\n')
+            break;
+        else if(buffer[pos] == '\b' && pos)
+            --pos;
+        else
+            ++pos;
+    }
+    buffer[pos] = 0;
+    return buffer;
+}
+
+int shell::inkey(const char *prompt)
+{
+    if(prompt && fsys::istty(shell::input()))
+        fputs(prompt, stdout);
+    else
+        return 0;
+
+    return (char)getch();
+}
+
+char *shell::getline(const char *prompt, char *buffer, size_t size)
+{
+    unsigned pos = 0;
+
+    if(!fsys::istty(shell::input()))
+        return fgets(buffer, size, stdin);
+
+    fputs(prompt, stdout);
+
+    while(pos < size - 1) {
+        buffer[pos] = (char)getch();
+        if(buffer[pos] == '\r' || buffer[pos] == '\n')
+            break;
+        else if(buffer[pos] == '\b' && pos) {
+            fputs("\b \b", stdout);
+            --pos;
+        }
+        else {
+            fputc(buffer[pos], stdout);
+            ++pos;
+        }
+        fflush(stdout);
+    }
+    printf("\n");
+    buffer[pos] = 0;
+    return buffer;
+}
+
 #else
 
 static const char *system_prefix = UCOMMON_PREFIX;
 
+#if defined(HAVE_TERMIOS_H)
+static struct termios io_prior, io_current;
+#elif defined(HAVE_TERMIO_H)
+static struct termio io_prior, io_current;
+#endif
+
+static void noecho(int fd)
+{
+#if defined(HAVE_TERMIOS_H)
+    tcgetattr(fd, &io_prior);
+    tcgetattr(fd, &io_current);
+    io_current.c_lflag &= ~ECHO;
+    tcsetattr(fd, TCSAFLUSH, &io_current);
+#elif defined(HAVE_TERMIO_H)
+    ioctl(fd, TCGETA, &io_prior);
+    ioctl(fd, TCGETA, &io_current);
+    io_current.c_lflag &= ~ECHO;
+    ioctl(fd, TCSETA, &io_current);
+#endif
+}
+
+static void echo(int fd)
+{
+#if defined(HAVE_TERMIOS_H)
+    tcsetattr(fd, TCSAFLUSH, &io_prior);
+#elif defined(HAVE_TERMIO_H)
+    ioctl(fd, TCSETA, &io_prior);
+#endif
+}
+
+char *shell::getline(const char *prompt, char *buffer, size_t size)
+{
+    size_t pos = 0;
+
+    if(!fsys::istty(input()))
+        return fgets(buffer, size, stdin);
+
+    noecho(1);
+    fputs(prompt, stdout);
+
+    while(pos < size - 1) {
+        buffer[pos] = ::getchar();
+        if(buffer[pos] == '\r' || buffer[pos] == '\n')
+            break;
+        else if(buffer[pos] == '\b' && pos) {
+            fputs("\b \b", stdout);
+            --pos;
+        }
+        else {
+            fputc(buffer[pos], stdout);
+            ++pos;
+        }
+        fflush(stdout);
+    }
+    printf("\n");
+    buffer[pos] = 0;
+    echo(1);
+    return buffer;
+}
+
+
+
+char *shell::getpass(const char *prompt, char *buffer, size_t size)
+{
+    size_t count;
+    int fd = ::open("/dev/tty", O_RDONLY);
+    if(-1 == fd)
+        fd = 1;
+
+    noecho(fd);
+    fputs(prompt, stderr);
+    count = ::read(fd, buffer, size);
+    if(count)
+        --count;
+    buffer[count] = 0;
+
+#if defined(HAVE_TERMIOS_H) || defined(HAVE_TERMIO_H)
+    fputs("\n", stderr);
+#endif
+    echo(fd);
+    if(fd != 1)
+        ::close(fd);
+    return buffer;
+}
+
+int shell::inkey(const char *prompt)
+{
+    if(!fsys::istty(1))
+        return 0;
+
+    noecho(1);
+    if(prompt)
+        fputs(prompt, stdout);
+    int ch = ::getchar();
+    echo(1);
+
+    return ch;
+}
+
 void shell::relocate(const char *argv0)
 {
 #ifdef  HAVE_REALPATH
